summaryrefslogtreecommitdiff
path: root/scripts/version.sh
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/version.sh')
-rwxr-xr-xscripts/version.sh9
1 files changed, 7 insertions, 2 deletions
diff --git a/scripts/version.sh b/scripts/version.sh
index be1b351..46b9fc5 100755
--- a/scripts/version.sh
+++ b/scripts/version.sh
@@ -1,6 +1,11 @@
#!/bin/sh
# The yChat Project (2005)
#
-# This script shows yChat VERSION-BRANCH
+# This script shows yChat VERSION-BRANCH Build BUILDNUMBER
+
+version=`grep VERSION src/msgs.h | head -n 1 | cut -d'"' -f2`
+branch=`grep BRANCH src/msgs.h | head -n 1 | cut -d'"' -f2`
+build=`grep BUILD src/msgs.h | tail -n 1 | cut -d' ' -f3`
+echo "yChat $version-$branch Build $build"
+
-sed -n 's/.*VERSION.*: \(.*\)".*/\1/p' src/msgs.h